@@ -10,8 +10,9 @@ from .exceptions import CimisError, CimisAPIError, CimisDataError, CimisConnecti
 from .models import WeatherData, Station, ZipCode, SpatialZipCode
 
 __version__ = "1.0.0"
-__author__ = "Mahipal Reddy Ramireddy"
+__author__ = "Mahipal Reddy Ramireddy, M. A. Andrade"
 __email__ = "mahipalbablu16@gmail.com"
+__maintainer__ = "Precision Irrigation Management Lab (PRIMA)"
 __description__ = "A comprehensive Python client for the California Irrigation Management Information System (CIMIS) API"
 
 __all__ = [
